@@ -20,7 +20,7 @@ template <class T>
 class AutoDeleteList : public QList<T*>
 {
 public:
-    AutoDeleteList() : QList<T*>() {}
+    AutoDeleteList() = default;
     ~AutoDeleteList()
     {
         // Remove from list first before deleting the pointer, in
@@ -34,5 +34,4 @@ public:
     AutoDeleteList& operator=(const AutoDeleteList&) = delete;
 };
 
-
 // vim: et sw=4:
