@@ -1,7 +1,7 @@
 /*
  *  fileresourcecalendarupdater.cpp  -  updates a file resource calendar to current KAlarm format
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2011-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2011-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -10,12 +10,10 @@
 
 #include "resources.h"
 #include "fileresource.h"
-
 #include "lib/messagebox.h"
+#include "kalarmcalendar/kacalendar.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/KACalendar>
-
 #include <KLocalizedString>
 
 #include <QTimer>
@@ -46,7 +44,7 @@ void FileResourceCalendarUpdater::updateToCurrentFormat(Resource& resource, bool
 
     if (containsResource(resource.id()))
         return;   // prevent multiple simultaneous user prompts
-    auto* updater = new FileResourceCalendarUpdater(resource, ignoreKeepFormat, parent, qobject_cast<QWidget*>(parent));
+    auto updater = new FileResourceCalendarUpdater(resource, ignoreKeepFormat, parent, qobject_cast<QWidget*>(parent));
     updater->update(true);
 }
 
@@ -88,7 +86,7 @@ bool FileResourceCalendarUpdater::update(bool useTimer)
                 mPromptMessage = conversionPrompt(mResource.displayName(), versionString, false);
                 if (useTimer)
                 {
-                    QTimer::singleShot(0, this, &FileResourceCalendarUpdater::prompt);
+                    QTimer::singleShot(0, this, &FileResourceCalendarUpdater::prompt);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
                     return true;
                 }
                 return prompt();
