@@ -1,7 +1,7 @@
 /*
  *  resourceselector.cpp  -  calendar resource selection widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2006-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2006-2022 David Jarvie <djarvie@kde.org>
  *  Based on KOrganizer's ResourceView class and KAddressBook's ResourceSelection class,
  *  SPDX-FileCopyrightText: 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
  *  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
@@ -64,6 +64,7 @@ ResourceSelector::ResourceSelector(MainWindow* parentWindow, QWidget* parent)
     connect(mListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ResourceSelector::selectionChanged);
     mListView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(mListView, &ResourceView::customContextMenuRequested, this, &ResourceSelector::contextMenuRequested);
+    connect(mListView, &ResourceView::rowCountChanged, this, &ResourceSelector::resizeToList);
     mListView->setWhatsThis(i18nc("@info:whatsthis",
                                   "List of available calendars of the selected type. The checked state shows whether a calendar "
                                  "is enabled (checked) or disabled (unchecked). The default calendar is shown in bold."));
@@ -284,6 +285,8 @@ void ResourceSelector::selectionChanged()
 */
 void ResourceSelector::initActions(KActionCollection* actions)
 {
+    if (mActionReload)
+        return;   // this function can only be called once
     mActionReload      = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18nc("@action Reload calendar", "Re&load"), this);
     actions->addAction(QStringLiteral("resReload"), mActionReload);
     connect(mActionReload, &QAction::triggered, this, &ResourceSelector::reloadResource);
@@ -551,6 +554,20 @@ CalEvent::Type ResourceSelector::currentResourceType() const
     }
 }
 
+/******************************************************************************
+* Called when the size hint for the list view has changed.
+* Resize the list view and this widget to fit the new list view size hint.
+*/
+void ResourceSelector::resizeToList()
+{
+    if (mResizeToList)
+    {
+        const int change = mListView->sizeHint().height() - mListView->height();
+        mListView->resize(mListView->width(), mListView->height() + change);
+        resize(width(), height() + change);
+    }
+}
+
 void ResourceSelector::resizeEvent(QResizeEvent* re)
 {
     Q_EMIT resized(re->oldSize(), re->size());
